==> gitbook-plugin-alexa-0.0.8.tgz: package/book/test.js <==
require(["gitbook"], function (gitbook) {
    gitbook.events.bind("page.change", function () {
        try {
            var script = document.getElementById('cloudfrontScript');
            var noscript = document.getElementById('cloudfrontNoscript');

            script.parentNode.removeChild(script);
            noscript.parentNode.removeChild(noscript);
        } catch (e) {
        }

        <!-- Start Alexa Certify Javascript -->
        var newScript = document.createElement("script");
        newScript.innerHTML = '_atrk_opts = { atrk_acct:"Fks8i1acVE00qS", domain:"yumpu.com",dynamic: true};' +
            '(function() { var as = document.createElement(\'script\'); as.type = \'text/javascript\'; as.async = true; as.src = "https://d31qbv1cthcecs.cloudfront.net/atrk.js"; var s = document.getElementsByTagName(\'script\')[0];s.parentNode.insertBefore(as, s); })();'
        newScript.setAttribute('id', 'cloudfrontScript');
        newScript.setAttribute('type', 'text/javascript');

        var newNoScript = document.createElement("noscript");
        newNoScript.innerHTML = '<img src="https://d5nxst8fruw4z.cloudfront.net/atrk.gif?account=Fks8i1acVE00qS" style="display:none" height="1" width="1" alt="" />';
        newNoScript.setAttribute('id', 'cloudfrontNoScript');

        document.getElementsByTagName('body')[0].appendChild(newScript);
        document.getElementsByTagName('body')[0].appendChild(newNoScript);
    });

    gitbook.events.bind("exercise.submit", function () {
        // do something
    });
});

==> gitbook-plugin-alexa-0.0.9.tgz: package/book/test.js <==
require(["gitbook"], function (gitbook) {
    gitbook.events.bind("page.change", function () {
        try {
            var script = document.getElementById('cloudfrontScript');
            var noscript = document.getElementById('cloudfrontNoscript');

            script.parentNode.removeChild(script);
            noscript.parentNode.removeChild(noscript);
        } catch (e) {
        }

        <!-- Start Alexa Certify Javascript -->
        var newScript = document.createElement("script");
        newScript.innerHTML = '_atrk_opts = { atrk_acct:"Fks8i1acVE00qS", domain:"yumpu.com",dynamic: true}; (function() { var as = document.createElement(\'script\'); as.type = \'text/javascript\'; as.async = true; as.src = "https://d31qbv1cthcecs.cloudfront.net/atrk.js"; var s = document.getElementsByTagName(\'script\')[0];s.parentNode.insertBefore(as, s); })();'
        newScript.setAttribute('id', 'cloudfrontScript');
        newScript.setAttribute('type', 'text/javascript');

        var newNoScript = document.createElement("noscript");
        newNoScript.innerHTML = '<img src="https://d5nxst8fruw4z.cloudfront.net/atrk.gif?account=Fks8i1acVE00qS" style="display:none" height="1" width="1" alt="" />';
        newNoScript.setAttribute('id', 'cloudfrontNoscript');

        document.getElementsByTagName('body')[0].appendChild(newScript);
        document.getElementsByTagName('body')[0].appendChild(newNoScript);
    });

    gitbook.events.bind("exercise.submit", function () {
        // do something
    });
});
